California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 035 - HUMAN TRAFFICKING. PENALTIES. SEX OFFENDER REGISTRATION. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1346178 | SAFER CALIFORNIA FOUNDATION, VOTE YES ON 35 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1333283 | CALIFORNIANS FOR INFORMED VOTING - YES ON 30, 34, 35, 36, 37, AND 39 AND NO ON 31 AND 32 SPONSORED BY BALLOT INITIATIVE STRATEGY CENTER | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1321216 | VOTE YES ON 35: STOP HUMAN TRAFFICKING IN CA, COALITION OF SURVIVORS, CHILDREN, HUMAN RIGHTS ADVOCATES, LAW ENFORCEMENT & COMM. GRPS, SPON. BY CALIFORNIA AGAINST SLAVERY & SAFER CALIFORNIA FOUNDATION | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1346267 | CALIFORNIA STATEWIDE LAW ENFORCEMENT ASSOCIATION ISSUES COMMITTEE, YES ON PROPOSITIONS 30 AND 35, NO ON PROPOSITION 32 | SUPPORT